@@ -1,6 +1,6 @@
 package SVG::Manual;
 
-our $VERSION = 2.33;
+our $VERSION = 2.35;
 use vars qw($VERSION);
 
 $VERSION = eval $VERSION;
@@ -11,7 +11,7 @@ SVG - Perl extension for generating Scalable Vector Graphics (SVG) documents
 
 =head2 VERSION
 
-Covers SVG-2.30 distribution
+Covers SVG-2.35 distribution
 
 =head1 SYNOPSIS
 
@@ -203,7 +203,7 @@ The Default SVG tag will generate the following XML:
         <defs  /><!--
         Generated using the Perl SVG Module V2.33
         by Ronan Oger
-        Info: http://www.roasp.com/
+        Info: http://www.roitsystems.com/
   -->
  </svg>
 
@@ -211,38 +211,28 @@ The Default SVG tag will generate the following XML:
 =head1 SEE ALSO
 
 perl(1), L<SVG::XML>, L<SVG::Element>, L<SVG::DOM>, L<SVG::Parser>
-L<http://www.roasp.com/>ROASP.com: Serverside SVG server with numerous SVG/Perl examples
-L<http://www.roasp.com/serverside>Serverside SVG discussion at ROASP.com
-L<http://www.vectoreal.com/>Vectoreal: Commercal SVG Application solutions
 L<http://www.roitsystems.com/>ROIT Systems: Commercial SVG perl solutions
 L<http://www.w3c.org/Graphics/SVG/>SVG at the W3C
 	
 
 =head1 AUTHOR
 
-Ronan Oger, RO IT Systemms GmbH, ronan@roasp.com
+Ronan Oger, RO IT Systems GmbH, cpan@roitsystems.com
 
 =head1 CREDITS
 
-Peter Wainwright, peter@roasp.com Excellent ideas, beta-testing, SVG::Parser
-Fredo, http://www.penguin.at0.net/~fredo/ - provided initial feedback
-for early SVG.pm versions and the idea of a simplified svg generator.
+Peter Wainwright, Excellent ideas, beta-testing, writing SVG::Parser and much of SVG::DOM.  Fredo, http://www.penguin.at0.net/~fredo/ - provided example code and initial feedback for early SVG.pm versions and the idea of a simplified svg generator.
 Adam Schneider, Brial Pilpr, Ian Hickson
+Martin Owens - SVG::DOM improvements in version 3.34
 
 =head1 EXAMPLES
 
-http://roasp.com/
+http://wiki.roitsystems.com/
 
 See also the examples directory in this distribution which contain several fully documented examples.
 
 =pod
 
-=head1 WINDOWS DISTRIBUTION
-
-http://roasp.com/ppm/
-
-=pod
-
 =head1 METHODS
 
 SVG provides both explicit and generic element constructor methods. Explicit
@@ -305,7 +295,7 @@ Furthermore, the following options:
 may also be set in xmlify, overriding any corresponding values set in the SVG->new declaration
 
 
-=head2 xmlify (alias: to_xml render)
+=head2 xmlify (alias: to_xml render serialise serialize)
 
 $string = $svg->xmlify(%attributes);
 
@@ -615,7 +605,9 @@ ECMAscript, Javascript or other compatible scripting language.
 
 B<Example:>
 
-    my $tag = $svg->script(-type=>"text/ecmascript");
+    my $tag = $svg->script(-type=>"text/ecmascript"); 
+    #or my $tag = $svg->script(); 
+    #note that type ecmascript is not Mozilla compliant
 
     # populate the script tag with cdata
     # be careful to manage the javascript line ends.
@@ -905,6 +897,13 @@ SEE ALSO:
 
   L<"cdata">, L<"script">.
 
+=head2 xmlescp and xmlescape
+
+$string = $svg->xmlescp($string)
+$string = $svg->xmlescape($string)
+
+SVG module does not xml-escape characters that are incompatible with the XML specification. B<xmlescp> and B<xmlescape> provides this functionality. It is a helper method which Generates an XML-escaped string for reserved characters such as ampersand, open and close brackets, etcetera.
+
 =head2 filter
 
 $tag = $svg->filter(%attributes)
@@ -1163,6 +1162,20 @@ The following L<SVG::DOM> elements are accessible through SVG:
 
 =item * setAttribute
 
+=item * insertBefore
+
+=item * insertAfter
+
+=item * insertSiblingBefore
+
+=item * insertSiblingAfter
+
+=item * replaceChild
+
+=item * removeChild
+
+=item * cloneNode
+
 =back
 
 =head1 LICENSE
@@ -1180,11 +1193,10 @@ L<SVG::Parser>,
 L<SVG::Manual>, 
 L<SVG::Extension>
 Serverside SVG Portal - Perl focused SVG site with discussion board and examples:
-L<http://www.roasp.com/>
+L<http://www.roitsystems.com/>
 L<http://www.perlsvg.com/>
 SVG at the W3C: L<http://www.w3c.org/Graphics/SVG/>
 For Commercial Perl/SVG development, refer to the following sites:
-Vectoreal:  L<http://www.vectoreal.com>
 RO IT Systems: L<http://www.roitsystems.com/>
 
 =cut
